@@ -8,8 +8,8 @@ from contextlib import redirect_stdout
 import doctest
 from io import StringIO
 import unittest
-from os.path import split, join
-from os import remove
+import os
+from pyiron_base import PythonTemplateJob
 from pyiron_base.project.generic import Project
 from abc import ABC
 from inspect import getfile
@@ -55,7 +55,7 @@ class PyironTestCase(unittest.TestCase, ABC):
         with StringIO() as buf, redirect_stdout(buf):
             result = doctest.testmod(self.docstring_module)
             output = buf.getvalue()
-        self.failIf(result.failed > 0, msg=output)
+        self.assertFalse(result.failed > 0, msg=output)
 
 
 class TestWithProject(PyironTestCase, ABC):
@@ -68,14 +68,14 @@ class TestWithProject(PyironTestCase, ABC):
         super().setUpClass()
         print("TestWithProject: Setting up test project")
         cls.project_path = getfile(cls)[:-3].replace("\\", "/")
-        cls.file_location, cls.project_name = split(cls.project_path)
+        cls.file_location, cls.project_name = os.path.split(cls.project_path)
         cls.project = Project(cls.project_path)
 
     @classmethod
     def tearDownClass(cls):
         cls.project.remove(enable=True)
         try:
-            remove(join(cls.file_location, "pyiron.log"))
+            os.remove(os.path.join(cls.file_location, "pyiron.log"))
         except FileNotFoundError:
             pass
 
@@ -88,4 +88,50 @@ class TestWithCleanProject(TestWithProject, ABC):
         self.project.remove_jobs_silently(recursive=True)
 
 
-_TO_SKIP = [PyironTestCase, TestWithProject, TestWithCleanProject]
+class ToyJob(PythonTemplateJob):
+    def __init__(self, project, job_name):
+        """A toyjob to test export/import functionalities."""
+        super(ToyJob, self).__init__(project, job_name)
+        self.input.data_in = 100
+
+    def write_input(self):
+        self.input.write(os.path.join(self.working_directory, "input.yml"))
+
+    # Allow writing of the input file
+    def _check_if_input_should_be_written(self):
+        return True
+
+    # This function is executed
+    def run_static(self):
+        self.status.running = True
+        self.output.data_out = self.input.data_in + 1
+        self.status.finished = True
+        self.to_hdf()
+        self.compress()
+
+
+class TestWithFilledProject(TestWithProject, ABC):
+
+    """
+    Tests that creates a projects, creates jobs and sub jobs in it, and at the end of unit testing,
+    removes the project.
+    """
+
+    @classmethod
+    def setUpClass(cls):
+        super().setUpClass()
+        job = cls.project.create_job(job_type=ToyJob, job_name="toy_1")
+        job.run()
+        job = cls.project.create_job(job_type=ToyJob, job_name="toy_2")
+        job.run()
+        job.status.aborted = True
+
+        with cls.project.open("sub_project") as pr_sub:
+            job = pr_sub.create_job(job_type=ToyJob, job_name="toy_1")
+            job.run()
+            job = pr_sub.create_job(job_type=ToyJob, job_name="toy_2")
+            job.run()
+            job.status.suspended = True
+
+
+_TO_SKIP = [PyironTestCase, TestWithProject, TestWithCleanProject, TestWithFilledProject]
