@@ -30,7 +30,7 @@ from pyiron_base.job.util import \
     _job_delete_files, \
     _job_delete_hdf, \
     _job_remove_folder
-from pyiron_base.settings.generic import Settings
+from pyiron_base.state import state
 
 __author__ = "Jan Janssen"
 __copyright__ = (
@@ -43,8 +43,6 @@ __email__ = "janssen@mpie.de"
 __status__ = "production"
 __date__ = "Sep 1, 2017"
 
-s = Settings()
-
 
 class JobCore(HasGroups):
     """
@@ -409,7 +407,7 @@ class JobCore(HasGroups):
         if len(self.child_ids) > 0:
             if _protect_childs:
                 if self._master_id is not None and not math.isnan(self._master_id):
-                    s.logger.error(
+                    state.logger.error(
                         "Job {0} is a child of a master job and cannot be deleted!".format(
                             str(self.job_id)
                         )
@@ -693,6 +691,7 @@ class JobCore(HasGroups):
         new_job_core._parent_id = self._parent_id
         new_job_core._master_id = self._master_id
         new_job_core._status = self._status
+        new_job_core._create_working_directory()
         if new_job_name == self.job_name:
             self.project_hdf5.copy_to(destination=hdf5_project.open(".."))
         else:
@@ -708,9 +707,13 @@ class JobCore(HasGroups):
 
         # Copy files outside the HDF5 file
         if copy_files and os.path.exists(self.working_directory):
+            if len(os.listdir(new_job_core.working_directory)) == 0:
+                os.rmdir(new_job_core.working_directory)
+            else:
+                raise RuntimeError("Target directory for copy not empty!")
             shutil.copytree(
                 self.working_directory,
-                new_job_core.working_directory,
+                new_job_core.working_directory
             )
         return new_job_core, file_project, hdf5_project, False
 
