@@ -17,22 +17,17 @@ from git import Repo, InvalidGitRepositoryError
 from warnings import warn
 from pyiron_base.project.path import ProjectPath
 from pyiron_base.database.filetable import FileTable
-from pyiron_base.settings.generic import Settings
-from pyiron_base.database.manager import DatabaseManager
-from pyiron_base.settings.publications import list_publications
+from pyiron_base.state import state
 from pyiron_base.database.performance import get_database_statistics
 from pyiron_base.database.jobtable import (
-    get_db_columns,
     get_job_ids,
     get_job_id,
     get_jobs,
-    job_table,
     set_job_status,
     get_child_ids,
     get_job_working_directory,
     get_job_status
 )
-from pyiron_base.settings.logger import set_logging_level
 from pyiron_base.generic.hdfio import ProjectHDFio
 from pyiron_base.generic.filedata import load_file
 from pyiron_base.generic.util import deprecate
@@ -51,6 +46,7 @@ from pyiron_base.server.queuestatus import (
 from pyiron_base.job.external import Notebook
 from pyiron_base.project.data import ProjectData
 from pyiron_base.archiving import import_archive, export_archive
+from typing import Generator
 
 __author__ = "Joerg Neugebauer, Jan Janssen"
 __copyright__ = (
@@ -63,9 +59,6 @@ __email__ = "janssen@mpie.de"
 __status__ = "production"
 __date__ = "Sep 1, 2017"
 
-s = Settings()
-dbm = DatabaseManager()
-
 
 class Project(ProjectPath, HasGroups):
     """
@@ -127,15 +120,21 @@ class Project(ProjectPath, HasGroups):
         self._data = None
         self._creator = Creator(project=self)
 
-        if not dbm.database_is_disabled:
-            dbm.open_connection()
-            self.db = dbm.database
-        else:
-            self.db = FileTable(project=path)
         self.job_type = JobTypeChoice()
 
         self._maintenance = None
 
+    @property
+    def state(self):
+        return state
+
+    @property
+    def db(self):
+        if not state.database.database_is_disabled:
+            return state.database.database
+        else:
+            return FileTable(project=self.path)
+
     @property
     def maintenance(self):
         if self._maintenance is None:
@@ -153,6 +152,7 @@ class Project(ProjectPath, HasGroups):
         return self.create_group("..")
 
     @property
+    @deprecate("use db.view_mode")
     def view_mode(self):
         """
         Get viewer_mode - if viewer_mode is enable pyiron has read only access to the database.
@@ -165,10 +165,7 @@ class Project(ProjectPath, HasGroups):
         Returns:
             bool: returns TRUE when viewer_mode is enabled
         """
-        if not isinstance(self.db, FileTable):
-            return self.db.viewer_mode
-        else:
-            return False
+        return self.db.view_mode
 
     @property
     def name(self):
@@ -248,7 +245,7 @@ class Project(ProjectPath, HasGroups):
         """
         job_id = self.get_job_id(new_job_name)
         if job_id is not None:
-            s.logger.info("create_from_job has already job_id {}!".format(job_id))
+            state.logger.info(f"create_from_job: {new_job_name} has already job_id {job_id}!")
             return None
 
         print("job_old: ", job_old.status)
@@ -258,7 +255,7 @@ class Project(ProjectPath, HasGroups):
             input_only=False,
             new_database_entry=True
         )
-        s.logger.debug(
+        state.logger.debug(
             "create_job:: {} {} from id {}".format(
                 self.path, new_job_name, job_old.job_id
             )
@@ -370,7 +367,7 @@ class Project(ProjectPath, HasGroups):
                  'timestop',
                  'totalcputime']
         """
-        return get_db_columns(self.db)
+        return self.db.get_table_headings()
 
     def get_jobs(self, recursive=True, columns=None):
         """
@@ -516,7 +513,8 @@ class Project(ProjectPath, HasGroups):
         """
         return self.load(job_specifier=job_specifier, convert_to_object=False)
 
-    def iter_jobs(self, path=None, recursive=True, convert_to_object=True, status=None, job_type=None, progress=True):
+    def iter_jobs(self, path: str = None, recursive: bool = True, convert_to_object: bool = True, progress: bool = True,
+                  **kwargs: dict) -> Generator:
         """
         Iterate over the jobs within the current project and it is sub projects
 
@@ -524,26 +522,15 @@ class Project(ProjectPath, HasGroups):
             path (str): HDF5 path inside each job object
             recursive (bool): search subprojects [True/False] - True by default
             convert_to_object (bool): load the full GenericJob object (default) or just the HDF5 / JobCore object
-            status (str/None): status of the jobs to filter for - ['finished', 'aborted', 'submitted', ...]
-            job_type (str/None): job type to filter for, corresponds to the 'hamilton' column in the job table
             progress (bool): if True (default), add an interactive progress bar to the iteration
+            **kwargs (dict): Optional arguments for filtering with keys matching the project database column name
+                            (eg. status="finished"). Asterisk can be used to denote a wildcard, for zero or more
+                            instances of any character
 
         Returns:
             yield: Yield of GenericJob or JobCore
         """
-        if status is None and job_type is None:
-            job_id_lst = self.get_jobs(recursive)["id"]
-        else:
-            df = self.job_table(recursive=True)
-            if df.empty:
-                job_id_lst = []
-            else:
-                mask = np.ones_like(df.index, dtype=bool)
-                if status is not None:
-                    mask &= df["status"] == status
-                if job_type is not None:
-                    mask &= df["hamilton"] == job_type
-                job_id_lst = list(df[mask]["id"])
+        job_id_lst = self.job_table(recursive=recursive, **kwargs)['id']
         if progress:
             job_id_lst = tqdm(job_id_lst)
         for job_id in job_id_lst:
@@ -604,27 +591,9 @@ class Project(ProjectPath, HasGroups):
         full_table=False,
         element_lst=None,
         job_name_contains='',
+        **kwargs: dict,
     ):
-        """
-        Access the job_table
-
-        Args:
-            recursive (bool): search subprojects [True/False] - default=True
-            columns (list): by default only the columns ['job', 'project', 'chemicalformula'] are selected, but the
-                            user can select a subset of ['id', 'status', 'chemicalformula', 'job', 'subjob', 'project',
-                            'projectpath', 'timestart', 'timestop', 'totalcputime', 'computer', 'hamilton',
-                            'hamversion', 'parentid', 'masterid']
-            all_columns (bool): Select all columns - this overwrites the columns option.
-            sort_by (str): Sort by a specific column
-            full_table (bool): Whether to show the entire pandas table
-            element_lst (list): list of elements required in the chemical formular - by default None
-            job_name_contains (str): a string which should be contained in every job_name
-
-        Returns:
-            pandas.Dataframe: Return the result as a pandas.Dataframe object
-        """
-        return job_table(
-            database=self.db,
+        return self.db.job_table(
             sql_query=self.sql_query,
             user=self.user,
             project_path=self.project_path,
@@ -634,8 +603,12 @@ class Project(ProjectPath, HasGroups):
             sort_by=sort_by,
             full_table=full_table,
             element_lst=element_lst,
-            job_name_contains=job_name_contains,
+            **kwargs,
         )
+    job_table.__doc__ = '\n'.join([
+        ll for ll in FileTable.job_table.__doc__.split('\n')
+        if not any([item in ll for item in ['sql_query (str)', 'user (str)', 'project_path (str)']])
+    ])
 
     def get_jobs_status(self, recursive=True, element_lst=None):
         """
@@ -753,12 +726,12 @@ class Project(ProjectPath, HasGroups):
             GenericJob, JobCore: Either the full GenericJob object or just a reduced JobCore object
         """
         if self.sql_query is not None:
-            s.logger.warning(
+            state.logger.warning(
                 "SQL filter '%s' is active (may exclude job) ", self.sql_query
             )
         job_id = self.get_job_id(job_specifier=job_specifier)
         if job_id is None:
-            s.logger.warning("Job '%s' does not exist and cannot be loaded", job_specifier)
+            state.logger.warning("Job '%s' does not exist and cannot be loaded", job_specifier)
             return None
         return self.load_from_jobpath(
             job_id=job_id, convert_to_object=convert_to_object
@@ -884,8 +857,7 @@ class Project(ProjectPath, HasGroups):
             *jobs (str, int): name of the job or job ID, any number of them
         """
         if len(jobs) == 0:
-            df = self.job_table()
-            jobs = df[df.status == "running"].id
+            jobs = self.job_table(status='running').id
         if self.db is not None:
             for job_specifier in jobs:
                 if isinstance(job_specifier, str):
@@ -969,7 +941,7 @@ class Project(ProjectPath, HasGroups):
                 try:
                     job = self.load(job_specifier=job_specifier, convert_to_object=False)
                     if job is None:
-                        s.logger.warning(
+                        state.logger.warning(
                             "Job '%s' does not exist and could not be removed",
                             str(job_specifier),
                         )
@@ -978,7 +950,7 @@ class Project(ProjectPath, HasGroups):
                     else:
                         job.remove()
                 except IOError as _:
-                    s.logger.debug(
+                    state.logger.debug(
                         "hdf file does not exist. Removal from database will be attempted."
                     )
                     job_id = self.get_job_id(job_specifier)
@@ -1032,9 +1004,9 @@ class Project(ProjectPath, HasGroups):
                 else:
                     try:
                         self.remove_job(job_specifier=job_id)
-                        s.logger.debug("Remove job with ID {0} ".format(job_id))
+                        state.logger.debug("Remove job with ID {0} ".format(job_id))
                     except (IndexError, Exception):
-                        s.logger.debug(
+                        state.logger.debug(
                             "Could not remove job with ID {0} ".format(job_id)
                         )
         else:
@@ -1133,18 +1105,14 @@ class Project(ProjectPath, HasGroups):
         Switch from user mode to viewer mode - if viewer_mode is enable pyiron has read only access to the database.
         """
         if not isinstance(self.db, FileTable):
-            dbm.switch_to_viewer_mode()
-            dbm.open_connection()
-            self.db = dbm.database
+            state.database.switch_to_viewer_mode()
 
     def switch_to_user_mode(self):
         """
         Switch from viewer mode to user mode - if viewer_mode is enable pyiron has read only access to the database.
         """
         if not isinstance(self.db, FileTable):
-            dbm.switch_to_user_mode()
-            dbm.open_connection()
-            self.db = dbm.database
+            state.database.switch_to_user_mode()
 
     def switch_to_local_database(self, file_name="pyiron.db", cwd=None):
         """
@@ -1154,26 +1122,14 @@ class Project(ProjectPath, HasGroups):
             file_name (str): file name or file path for the local database
             cwd (str): directory where the local database is located
         """
-        if cwd is None:
-            cwd = self.path
-        if not dbm.project_check_enabled:
-            dbm.switch_to_local_database(file_name=file_name, cwd=cwd)
-            super(Project, self).__init__(path=self.path)
-        else:
-            dbm.switch_to_local_database(file_name=file_name, cwd=cwd)
-        self.db = dbm.database
+        cwd = self.path if cwd is None else cwd
+        state.database.switch_to_local_database(file_name=file_name, cwd=cwd)
 
     def switch_to_central_database(self):
         """
         Switch from local mode to central mode - if local_mode is enable pyiron is using a local database.
         """
-        dbm.switch_to_central_database()
-        if not dbm.database_is_disabled:
-            dbm.open_connection()
-            self.db = dbm.database
-        else:
-            self.db = FileTable(project=self.path)
-            super(Project, self).__init__(path=self.path)
+        state.database.switch_to_central_database()
 
     def queue_delete_job(self, item):
         """
@@ -1255,7 +1211,7 @@ class Project(ProjectPath, HasGroups):
         Returns:
             pandas.DataFrame/ list: list of publications in Bibtex format.
         """
-        return list_publications(bib_format=bib_format)
+        return state.publications.show(bib_format=bib_format)
 
     @staticmethod
     def queue_is_empty():
@@ -1330,6 +1286,7 @@ class Project(ProjectPath, HasGroups):
         )
 
     @staticmethod
+    @deprecate(message="Use state.logger.set_logging_level instead.")
     def set_logging_level(level, channel=None):
         """
         Set level for logger
@@ -1338,7 +1295,7 @@ class Project(ProjectPath, HasGroups):
             level (str): 'DEBUG, INFO, WARN'
             channel (int): 0: file_log, 1: stream, None: both
         """
-        set_logging_level(level=level, channel=channel)
+        state.logger.set_logging_level(level=level, channel=channel)
 
     @staticmethod
     def list_clusters():
@@ -1348,7 +1305,7 @@ class Project(ProjectPath, HasGroups):
         Returns:
             list: List of computing clusters
         """
-        return s.queue_adapter.list_clusters()
+        return state.queue_adapter.list_clusters()
 
     @staticmethod
     def switch_cluster(cluster_name):
@@ -1358,7 +1315,7 @@ class Project(ProjectPath, HasGroups):
         Args:
             cluster_name (str): name of the computing cluster
         """
-        s.queue_adapter.switch_cluster(cluster_name=cluster_name)
+        state.queue_adapter.switch_cluster(cluster_name=cluster_name)
 
     @staticmethod
     def _is_hdf5_dir(item):
@@ -1460,7 +1417,7 @@ class Project(ProjectPath, HasGroups):
 
             pattern = posixpath.join(self.path, pattern)
             for f in glob.glob(pattern):
-                s.logger.info("remove file {}".format(posixpath.basename(f)))
+                state.logger.info("remove file {}".format(posixpath.basename(f)))
                 os.remove(f)
         else:
             raise EnvironmentError("copy_to: is not available in Viewermode !")
@@ -1523,7 +1480,7 @@ class Project(ProjectPath, HasGroups):
         Add a new creator to the project class.
 
         Example)
-        
+
         >>> from pyiron_base import Project, Toolkit
         >>> class MyTools(Toolkit):
         ...     @property
@@ -1601,12 +1558,11 @@ class GlobalMaintenance:
         initialize the flag self._check_postgres, to control whether pyiron is
         set to communicate with a postgres database.
         """
-        s = Settings()
-        connection_string = s._configuration['sql_connection_string']
+        connection_string = state.database.sql_connection_string
         if "postgresql" not in connection_string:
             warn(
                 """
-                The detabase statistics is only available for a Postgresql database
+                The database statistics is only available for a Postgresql database
                 """
             )
             self._check_postgres = False
